

/**********************************************************************************************************
This SAS program generates the sample used in the paper, titled "Facial Structure and Achievement Drive: Evidence from Financial Analysts"
The input data include: 
1) the raw data downloaded from CBAS;
2) the raw data downloaded from CSMAR;
3) the manually collected and cleaned data for analysts' facial width-to-height ratio (fWHR), analysts' ages, titles and firms' R&D expenses. 
The program include: 
1) Variable construction using the main regression analysis;
2) Variable construction for the subsample analysis.
**************************************************************************************************************/
libname fwhr "D:\HYZZZ JAR";



/*Extract annual earnings forecasts from CBAS for the period of 2004-2014. Before merging with the data of fWHR,
we extract individual analyst ID code for forecasts issued by a group of analysts.*/

data forecast;
set fwhr.forecast;/*Annual earnings forecasts from CBAS in December 2015*/
if 2004<=year(fpenddt)<=2014;
eyear=year(fpenddt);
ayear=year(anndats);
n=_n_;
andat=anndats;
fendt=fpenddt;
andat_act=anndats_act;
format andat fendt andat_act yymmdd10.;
i=1;
do while (kscan(a_code,i,'/' )^='');
a_code1=kscan(a_code,i,'/');
output;
i+1;
end;
run;



/*Merge with fWHR*/

/*
fwhr.fwhr is the manually collected and cleaned dataset of analysts' facial width-to-height ratio.
whr is the fWHR of analysts who have their ID pictures available on the website of Securities Association of China (SAC). 
The values of "whr" in the "fwhr.fwhr" file are,the average of the two RAs' measures of fWHR (as described in the paper). 
"lowquality" is a dummy variable that equals one if the picture quality is low. The definition of low picture quality is described in the paper. 
*/



proc sql;
create table forecast as 
select a.*,b.whr,b.lowquality
from forecast a 
left join fwhr.fwhr b
on kcompress(kstrip(a.a_code1))=kcompress(kstrip(b.a_code));
quit;


/*Forecast accuracy calculation*/

proc import out=actual
datafile="D:\HYZZZ JAR\actual.xlsx" /*the dataset including actual earnings from CBAS*/
dbms=xlsx replace;
run;

data actual;
set actual;
format fpenddt yymmdd10.;
run;


proc sql;
create table forecast as 
select a.*,b.eps_act
from forecast a 
left join actual  b 
on a.s_code=b.s_code and a.fpenddt=b.fpenddt;
quit;


proc sql;
create table price as
select distinct a.s_code,a.andat,b.trddt,b.clsprc as price,(a.andat-input(b.trddt,yymmdd10.)) as diff,min(a.andat-input(b.trddt,yymmdd10.))  as first
from forecast a 
left join fwhr.price b /*the dataset including daily stock price from CSMAR*/
on a.s_code=b.stkcd and a.andat between input(b.trddt,yymmdd10.)+2 and input(b.trddt,yymmdd10.)+20
group by a.s_code,a.andat;
quit;

data price;
set price;
if diff eq first;
drop diff first;
run;

proc sql;
create table forecast as
select a.*,abs(a.feps-a.eps_act)/b.price as absafep
from forecast a 
left join price b 
on a.s_code=b.s_code and a.andat=b.andat ;
quit;

/*More independent variables (forecast frequency, lagaccuracy, dayselap) are calculated before sample selection*/

proc sql;
create table forecast as
select a.*,count(distinct andat) as fnum
from forecast a
group by s_code,a_code1,eyear;
quit;

proc sort data=forecast;
by s_code a_code1 eyear  andat;
run;


data forecast;
set forecast;
by s_code a_code1 eyear  andat;
j+1;
if first.eyear then j=1;
run;

proc sql;
create table forecast as
select a.*,b.absafep as lagabsfep,b.feps as lagfeps
from forecast a
left join forecast b
on a.s_code=b.s_code and a.eyear=b.eyear and a.a_code1=b.a_code1 and a.j=b.j+1;
quit;


proc sql;
create table dayelaps as 
select distinct s_code, eyear,andat 
from forecast a ;
quit;


proc sort data=dayelaps;
by s_code eyear  andat;
run;

data dayelaps;
set dayelaps;
by s_code eyear andat;
k+1;
if first.s_code then k=1;
run;

proc sql;
create table dayelaps as 
select a.*,b.andat as elagandat 
from dayelaps a 
left join dayelaps b 
on a.s_code=b.s_code and a.eyear=b.eyear and a.k=b.k+1;
quit;

proc sql;
create table forecast as
select a.*,a.andat-b.elagandat as elaps
from forecast a 
left join dayelaps b 
on a.s_code=b.s_code and a.eyear=b.eyear and a.andat=b.andat;
quit;



/* Select the sample*/

data forecast;
set forecast;
/*drop forecasts issued by a group of analysts*/
if kindex(a_code,"/") gt 0 then delete;
/*drop forecasts issued less than 30 days before earnings announcement*/
if andat_act-andat>30;
run;

/*keep most recent forecast before earnings announcement*/
proc sort data=forecast;by s_code eyear a_code1 descending andat;run;

proc sort data=forecast nodupkey;by s_code eyear a_code1;run;


/*Calculate other control variables (brokersize, experience, companies, industries, analystage and postgraduate)*/
proc sql;
create table forecast as
select distinct a.*,count(distinct a_code1) as broker
from forecast a
group by ayear,b_code;
quit;


proc sql;
create table exp as 
select distinct s_code,ayear,a_code1,(ayear-min(ayear)) as exp
from forecast
group by s_code,a_code1
order by s_code,a_code1;
quit;


proc sql;
create table forecast as 
select a.*,b.exp
from forecast a 
left join exp b 
on a.s_code=b.s_code and a.ayear=b.ayear and a.a_code1=b.a_code1;
quit;

proc sql;
create table forecast as
select distinct a.*,count(distinct s_code) as numcompany
from forecast a
group by eyear,a_code1;
quit;


proc import out=ind
datafile='D:\HYZZZ JAR\FI_T1.dbf'/*dataset including industry code from CSMAR*/
dbms=dbf replace;
run;

data ind;
set ind;
if substr(accper,6,2) ="12";
if Typrep="A";
run;

proc sql;
create table forecast as 
select a.*,b.indcd 
from forecast a 
left join ind  b 
on a.s_code=b.stkcd and eyear=input(substr(accper,1,4),best12.);
quit;

data forecast;
set forecast;
ind=substr(indcd,1,1);
if substr(indcd,1,1)='C' then ind=indcd;
if ind=' ' then delete;
run;


proc sql;
create table forecast as
select distinct a.*,count(distinct ind) as numind
from forecast a
group by eyear,a_code1
order by eyear,a_code1;
quit;

proc sort data=forecast;by eyear a_code1 ind;run;


data basic;
set fwhr.basic;/*dataset including analysts' basic information from CBAS and manual collection*/
gender=(sex='');
if kindex(high_degree,'˶ʿ') gt 0 or kindex(high_degree,'ʿ') gt 0 then postgraduate=1;else postgraduate=0;
run;


proc sql;
create table forecast as 
select *
from forecast a 
left join basic b 
on a.a_code1=b.a_code;
quit;

data forecast;
set forecast;
age=ayear-birth_year;
run;


/*Winsorize continous variables*/

%include "D:\HYZZZ JAR\winsor.txt";
%winsor(dsetin=forecast, dsetout=forecast,byvar=none, vars=absafep lagabsfep elaps fnum broker exp numcompany numind age,  type=winsor, pctl=1 99);



/*Scale the variables into range between 0 and 1 following Clement and Tse 2005*/
proc sql;
create table forecast as 
select *,(max(absafep)-absafep)/(max(absafep)-min(absafep)) as accuracy,
	(max(lagabsfep)-lagabsfep)/(max(lagabsfep)-min(lagabsfep)) as lagaccuracy,
	((elaps)-min(elaps))/(max(elaps)-min(elaps)) as dayselap,
	(fnum-min(fnum))/(max(fnum)-min(fnum)) as frequency, 
	(intck('day',andat,fendt)-min(intck('day',andat,fendt)))/(max(intck('day',andat,fendt))-min(intck('day',andat,fendt))) as horizon,
	(broker-min(broker))/(max(broker)-min(broker)) as brokersize, 
	(exp-min(exp))/(max(exp)-min(exp)) as experience,
	(numcompany-min(numcompany))/(max(numcompany)-min(numcompany)) as companies,
	(numind-min(numind))/(max(numind)-min(numind)) as industries,
	(age-min(age))/(max(age)-min(age)) as analystage
from forecast
group by s_code,eyear;
quit;


data forecast;
set forecast;
/*drop financial industry*/
if ind='J' then delete; 
/*only keep male analysts*/
if gender=1; 
/*only keep analysts with high-quality pictures*/
if lowquality=0; 
run;

/*Define DfWHR*/

proc sort data=forecast out=analyst nodupkey;by a_code1;run;

proc means data=analyst median noprint;
var whr;
output out=analyst_whr median=median_whr;
run;

proc sql;
create table forecast
as select distinct a.*,b.median_whr
from forecast as a,analyst_whr as b;
quit;

data forecast;
set forecast;
if whr^=. then dfwhr=(whr gt median_whr);
run;



data forecast;
set forecast;
array vars whr accuracy lagaccuracy dayselap frequency horizon brokersize experience companies industries analystage postgraduate;
  do over vars;
	 if vars="."  then delete;
	end;
run;



/* Part 2: Subsample Analysis */


/*Table 4 */
proc import out=brokerassets
datafile="D:\HYZZZ JAR\Broker_financial.xlsx" /*dataset including financial information of brokerage firms from CBAS*/
dbms=excel replace;
run;

proc sort data=brokerassets;
by b_code date source;
run;

proc sort data=brokerassets nodupkey;
by b_code date;
run;

proc sql;
create table forecast  as
select a.*,b.t_assets as lagbrokerassets
from forecast a
left join brokerassets b
on a.b_code=b.b_code and a.ayear=year(b.date)+1;
quit;

proc means data=forecast median noprint;
var lagbrokerassets;
output out=broker_lagassets median=median_lagbrokerassets;
run;

proc sql;
create table forecast
as select distinct a.*,b.median_lagbrokerassets
from forecast as a,  broker_lagassets as b;
quit;



data forecast;
set forecast;
dbrokerassets=(lagbrokerassets gt median_lagbrokerassets);
if lagbrokerassets=. then dbrokerassets=.;
run;



proc sql;
create table forecast as 
select a.*,b.highstatus
from forecast a 
left join fwhr.title b /*fwhr.title is a manually cleaned dataset including analysts' high/low titles*/
on kcompress(kstrip(a.a_code1))=kcompress(kstrip(b.a_code))
   and a.andat between b.startdate and b.enddate;
quit;

proc sort data=forecast ;
by s_code a_code1 andat  descending highstatus;
run;

proc sort data=forecast nodupkey;
by s_code a_code1 andat eyear;
run;

data forecast;
set forecast;
if highstatus=. then highstatus=0;
run;



/*Table 5*/

proc import out=fsba
datafile='D:\HYZZZ JAR\FS_COMba.dbf'/*dataset including financial data from balance sheet of listed firms from CSMAR*/
dbms=dbf replace;
run;


proc import out=fscf
datafile='D:\HYZZZ JAR\FS_COMSC.dbf'/*dataset includingfinancial data from cash flow statement of listed firms from CSMAR*/
dbms=dbf replace;
run;

data fsba;
set fsba;
if substr(accper,6,2) eq '12';
if typrep='A';
year=substr(accper,1,4)+0;
run;

proc sql;
create table fin as 
select a.stkcd,a.accper,a.typrep, a.year, b.C001000000/a.A004000000 as cfoat
from fsba a left join fscf b
on a.stkcd=b.stkcd and a.accper=b.accper and a.typrep=b.typrep;
quit;

proc sql;
create table vola5 as 
select distinct a.stkcd,a.accper,a.year,std(b.cfoat) as cfvol
from fin a left join fin b 
on a.stkcd=b.stkcd and a.year-b.year>0 and a.year-b.year<=5 
group by a.stkcd,a.year;
quit;


proc sql;
create table forecast as
select a.*,b.cfvol
from forecast a left join vola5 b
on a.s_code=b.stkcd and a.ayear=b.year+1;
quit;

proc import out=ipo
datafile='D:\HYZZZ JAR\IPO_Cobasic.xlsx'/*dataset including IPO characteristics from CSMAR*/
dbms=excel replace;
run;


proc sql;
create table forecast 
as select a.*,ayear-year(input(listdt,yymmdd10.))+1 as firmage
from forecast a left join ipo b 
on a.s_code=b.stkcd ;
quit;

data forecast;
set forecast;
if firmage le 5 then cfvol=.;
run;

proc sort data=forecast out=cfvol nodupkey;by s_code ayear;run;

proc means data=cfvol median noprint;
var cfvol;
class ayear;
output out=cfvol1 median=median_cfvol;
run;

proc sql;
create table forecast
as select distinct a.*,b.median_cfvol
from forecast as a
left join cfvol1 as b
on  a.ayear=b.ayear;
quit;

data forecast;
set forecast;
dcfvol=(cfvol gt median_cfvol);
if cfvol=. then dcfvol=.;
run;


proc sql;
create table forecast as
select a.*,b.rd
from forecast a left join fwhr.rd b /*fwhr.rd includes mannually cleaned R&D expense of listed firms,raw datasets are from CSMAR*/
on a.s_code=b.stkcd and a.ayear=b.year;
quit;

data forecast;
set forecast;
drd=(rd gt 0);
run;




/*Table 6*/

proc sql;
create table coverage as 
select distinct s_code,ayear,a_code1
from forecast a ;
quit;


proc sql;
create table coverage as 
select *,count(a_code1) as cover
from coverage a 
group by s_code,ayear;
quit;

proc sort data=coverage  nodupkey;
by s_code ayear;
run;


proc sql;
create table forecast 
as select a.*,b.cover as coverage
from forecast a
left join coverage b
on a.s_code=b.s_code and a.ayear=b.ayear+1;
quit;

data forecast;
set forecast;
if coverage=. then coverage=0;
run;

proc sort data=forecast out=lagcoverage nodupkey;by s_code ayear;run;

proc means data=lagcoverage median noprint;
var coverage;
class ayear;
output out=firm_lagcoverage median=median_coverage;
run;

proc sql;
create table forecast
as select distinct a.*,b.median_coverage
from forecast as a
left join firm_lagcoverage as b
on  a.ayear=b.ayear;
quit;

data forecast;
set forecast;
dcoverage=(coverage gt median_coverage);
run;


proc sql;
create table forecast as
select a.*,b.bull
from forecast a 
left join fwhr.mktsentiment b /*dataset including whether Shanghai Composite Index return exceeds one-year risk-free rate, raw datasets are from CSMAR*/
on a.ayear=b.year;
quit;



/**********************************************************************************************************
Data analysis starts here 
**************************************************************************************************************/


